<?php
/**
 * Déclarations relatives à la base de données
 *
 * @plugin     Subdivisions Géographiques
 * @copyright  2020
 * @author     Vincent CALLIES
 * @licence    GNU/GPL
 * @package    SPIP\Subdivisions\Base
 */

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}


/**
 * Déclaration des alias de tables et filtres automatiques de champs
 *
 * @pipeline declarer_tables_interfaces
 * @param array $interfaces
 *     Déclarations d'interface pour le compilateur
 * @return array
 *     Déclarations d'interface pour le compilateur
 */
function subdivisions_declarer_tables_interfaces($interfaces) {

	$interfaces['table_des_tables']['subdivisions'] = 'subdivisions';
	
	$interfaces['table_des_traitements']['NOM_USAGE']['sudivisions']= _TRAITEMENT_TYPO;
 	
 	return $interfaces;
}


/**
 * Déclaration des objets éditoriaux
 *
 * @pipeline declarer_tables_objets_sql
 * @param array $tables
 *     Description des tables
 * @return array
 *     Description complétée des tables
 */
function subdivisions_declarer_tables_objets_sql($tables) {

	$tables['spip_subdivisions'] = array(
		'texte_retour' => 'icone_retour',
		'texte_objets' => 'subdivision:titre_subdivisions',
		'texte_objet' => 'subdivision:titre_subdivision',
		'texte_modifier' => 'subdivision:icone_modifier_subdivision',
		'texte_creer' => 'subdivision:icone_creer_subdivision',
		'info_aucun_objet'=> 'subdivision:info_aucune_subdivision',
		'info_1_objet' => 'subdivision:info_1_subdivision',
		'info_nb_objets' => 'subdivision:info_nb_subdivisions',
		'texte_logo_objet' => 'subdivision:titre_logo_subdivision',
		'texte_langue_objet' => 'subdivision:titre_langue_subdivision',
		'type' => 'subdivision',
		'principale' => 'oui',
		'field'=> array(
			'id_subdivision'	=> 'bigint(21) NOT NULL',
			'iso_moi' => "varchar(6) DEFAULT '' NOT NULL", // qui suis-je ISO 3166-2
			'iso_parent' => "varchar(6) DEFAULT '' NOT NULL", // sans parent, je suis la 1ère subdivision ISO 3166-2
			'iso_pays' => "char(2) DEFAULT '' NOT NULL",   //  ISO 3166 alpha2
			'nuts'	=> "varchar(6) NOT NULL default ''", // le code européen NUTS
			'specifique' => "varchar(255) DEFAULT '' NOT NULL",  // à votre usage, comme le cog spécifiquement français
			'titre' => 'text NOT NULL', // nom multi
			'nom_usage' => 'text NOT NULL', // nom d'usage multi. Les surnoms, c'est si convivial
			'date' => "datetime DEFAULT '0000-00-00 00:00:00' NOT NULL",
			'statut' => "varchar(255) DEFAULT '0' NOT NULL",
			'maj' => "TIMESTAMP NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP"
		),
		'key' => array(
			'PRIMARY KEY' => 'id_subdivision',
			"KEY iso_parent"	=> "iso_parent",
			"KEY iso_pays" => "iso_pays",
			'KEY nuts' => 'nuts',
		),
		'titre' => 'titre AS titre, "" AS lang',
		'date' => "date",
		'champs_editables'  => array('iso_moi', 'iso_parent', 'iso_pays', 'nuts', 'specifique', 'titre', 'nom_usage'),
		'champs_versionnes' => array('iso_moi', 'iso_parent', 'iso_pays', 'nuts', 'specifique', 'titre', 'nom_usage'),
		'rechercher_champs' => array("titre" => 1, "nom_usage" => 2,  "iso_moi" => 6, "nuts" => 5, "specifique" => 8),
		'tables_jointures' => array( 'subdivisions_liens' ),
		'statut'=> array(
			array(
				'champ' => 'statut',
				'publie' => 'publie',
				'previsu' => 'publie,prop,prepa',
				'post_date' => 'date',
				'exception' => array('statut','tout')
			)
		),
		'statut_textes_instituer' => 	array(
			'prepa' => 'texte_statut_en_cours_redaction',
			'prop' => 'texte_statut_propose_evaluation',
			'publie' => 'texte_statut_publie',
			'refuse' => 'texte_statut_refuse',
			'poubelle' => 'texte_statut_poubelle'
		),
		'texte_changer_statut' => 'subdivision:texte_changer_statut'		
	);


 return $tables;
}

/**
 * Déclaration des tables auxiliaires
 *
 * @pipeline declarer_tables_objets_sql
 * @param array $tables
 *     Description des tables
 * @return array
 *     Description complétée des tables
 */

function subdivisions_declarer_tables_auxiliaires($tables) {
 $tables['spip_subdivisions_liens'] = array(
  'field' => array(
	"id_subdivision" => "bigint(21) NOT NULL DEFAULT '0'",
	"id_objet" => "bigint(21) DEFAULT '0' NOT NULL",
	"objet" => "VARCHAR(25) DEFAULT '' NOT NULL",
	"role" => "varchar(30) NOT NULL DEFAULT ''",
	),
  'key' => array(
	"PRIMARY KEY" => "id_subdivision,id_objet,objet,role",
	"KEY id_subdivision" => "id_subdivision",
	"KEY id_objet" => "id_objet",
	"KEY objet" => "objet",
	"KEY role" => "role",
	),
 );

 return $tables;
}
